@@ -34,13 +34,15 @@ def org_option(f):
         return value
 
     return click.option(
+        '-o',
         '--org',
         prompt="Org id",
         hide_input=False,
         default=None,
         required=True,
         type=click.INT,
-        callback=callback
+        callback=callback,
+        help='Specify which org to work with'
     )(f)
 
 
