@@ -36,16 +36,24 @@ def org():
 
 
 @org.command('list')
-@click.option('--table', prompt=False, default=True, required=False, type=click.BOOL)
+@click.option('--table', prompt=False, default=True, required=False, type=click.BOOL, help='True displays a table. --org implies False')
+@click.option('-o', '--org', type=click.INT, default=-1, show_default=False, help="Include an org id to list a single org")
 @cluster_options
-def org_list(table, remote):
+def org_list(table, remote, org):
     try:
-        response = ApiManager(cluster=remote).orgs.get_org_list()
+        response = None
+        if org > 0:
+            response, resp_code = ApiManager(cluster=remote).orgs.get_org_info(org)
+            table = False
+        else:
+            response = ApiManager(cluster=remote).orgs.get_org_list()
 
         if table:
-            response = tabulate_from_json(response)
+            click.echo(click.style(tabulate(response, "keys"), blink=False, bold=True, fg='green'))
+        else:
+            click.echo(click.style(response, blink=False, bold=True, fg='green'))
+
 
-        click.echo(click.style(tabulate(response, "keys"), blink=False, bold=True, fg='green'))
 
     except Exception as err:
         click.echo(click.style(str(err), blink=False, bold=True, fg='red'))
@@ -84,6 +92,16 @@ def org_delete(org, name, remote):
     except Exception as err:
         click.echo(click.style(str(err), blink=False, bold=True, fg='red'))
 
+@org.command('meta')
+@click.option('-m', '--metadata', type=click.STRING)
+@click.option('--merge/--no-merge', default=True, help='Merge (or not) the JSON with the existing metadata field')
+@org_cluster_options
+def org_update_metadata(org, metadata, merge, remote):
+    try:
+        response = ApiManager(cluster=remote).orgs.update_org_metadata(org_id=org, metadata=metadata, merge=merge)
+        click.echo(click.style(str(response), blink=False, bold=True, fg='green'))
+    except Exception as err:
+        click.echo(click.style(str(err), blink=False, bold=True, fg='red'))
 
 @org.command('expiry')
 @click.option('--days', default=None, hide_input=False, confirmation_prompt=False, type=click.INT)
